#!/usr/bin/env bash
#
# Install this agent as a system service and set to start on boot.

HERE="$(dirname $0)"
PREFIX="/Library/eVAL/ManagedDeviceAgent"
JAR="ManagedDeviceAgent-2.1.0-all.jar"
JAVATGZ="OpenJDK11U-jre_x64_mac_hotspot_11.0.11_9.tar.gz"
JDKDIR="jdk-11.0.11+9-jre"





if [ "$(whoami)" != "root" ]; then
	echo "Please run this script as root!"
	exit 1
fi

# Download a new version!
echo "Retrieving basescript bootstrap script..."
if [ ! -e "/Library/eVAL" ]; then
	mkdir -p "/Library/eVAL"
fi
curl https://mirror.eval.bz/eval.basescript/basescript.sh > "/Library/eVAL/basescript.sh"
echo "Loading basescript..."
source "/Library/eVAL/basescript.sh"


# Monkeypatch MacOS support
OSVERSION="$(sw_vers | grep ProductVersion | sed 's#.*:##' | xargs)"
OSVERSIONMAJ="$(sw_vers | grep ProductVersion | sed 's#.*:##' | xargs | sed 's:\([0-9]*\)\.\([0-9]*\)\..*:\1:')"
OSVERSIONMIN="$(sw_vers | grep ProductVersion | sed 's#.*:##' | xargs | sed 's:\([0-9]*\)\.\([0-9]*\)\..*:\2:')"


printheader ""
printline "By continuing with this application, you agree to allow your"
printline "managed service provider to remotely execute commands"
printline "on this local computer in order to provide support,"
printline "maintenance, and manage security issues."
printheader ""
echo -n "Press [ENTER] to continue"
read TRASH




printheader "Setting up directory structure"

# Setup the directory structure.
safemkdir "$PREFIX/bin"
safemkdir "$PREFIX/etc"
safemkdir "$PREFIX/lib"



printheader "Installing dependencies"

if [ "$OSVERSIONMAJ" == "10" -a "$OSVERSIONMIN" -le 13 ]; then
	# MacOS 10.13 ships with python2; we'll need homebrew to install.

	if [ -z "$(which brew)" ]; then
		/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)"
		export PATH="/usr/local/opt/python/libexec/bin:$PATH"
	fi

	if [ -z "$(which python3)" ]; then
		brew install python
	fi

	python3 -c 'import six'
	if [ $? -ne 0 ]; then
		pip3 install six
	fi

	python3 -c 'import dateutil'
	if [ $? -ne 0 ]; then
		pip3 install python-dateutil
	fi
fi


# Copy the jar into the bin directory for this project.
cp "${HERE}/resources/${JAR}" "${PREFIX}/bin/ManagedDeviceAgent.jar"
tar -C "${PREFIX}/lib" -xzf "${HERE}/resources/${JAVATGZ}"
mv "${PREFIX}/lib/${JDKDIR}" "${PREFIX}/lib/jre"


if [ ! -e "$PREFIX/etc/system.properties" ]; then
	printheader ""
	printline "A management server URL is required for this agent."
	printline "If you do not know this, please contact your MSP."
	printheader ""
	echo -n "Press enter the management URL: "
	read SERVERURL

	if [ "${SERVERURL/:\/\/}" == "${SERVERURL}" ]; then
		SERVERURL="https://${SERVERURL}"
	fi

	if [ "${SERVERURL/https:\/\/}" == "${SERVERURL}" ]; then
		SSL="0"
	else
		SSL="1"
	fi


	printheader ""
	printline "For privacy concerns, remote desktop access requires"
	printline "user approval prior to a technician connecting."
	printline ""
	printline "Unattended setups for servers can be enabled if necessary."
	printheader ""
	echo -n "Enable unattended access? (y/N): "
	read UNATTENDED

	case "$UNATTENDED" in
		"y" | "Y" | "yes" | "YES")
			UNATTENDED="1"
			;;
		*)
			UNATTENDED="0"
	esac

	SERVERURL="${SERVERURL/:/\\:}"

	echo "server=${SERVERURL}" >> "$PREFIX/etc/system.properties"
	echo "ssl=${SSL}" >> "$PREFIX/etc/system.properties"
	echo "unattended=${UNATTENDED}" >> "$PREFIX/etc/system.properties"
fi



printheader "Installing and starting service"

cp "$HERE/resources/bz.eval.manageddeviceagent.plist" "/Library/LaunchDaemons/bz.eval.manageddeviceagent.plist"
launchctl load /Library/LaunchDaemons/bz.eval.manageddeviceagent.plist
launchctl enable system/bz.eval.manageddeviceagent
launchctl start system/bz.eval.manageddeviceagent

cp "$HERE/resources/bz.eval.manageddevicegui.plist" "/Library/LaunchAgents/bz.eval.manageddevicegui.plist"
launchctl load /Library/LaunchAgents/bz.eval.manageddevicegui.plist
launchctl enable user/bz.eval.manageddevicegui
launchctl start user/bz.eval.manageddevicegui


printsuccess "Management Agent Installed!"
